@@ -1,50 +1,15 @@
 use v5.26;
 use Object::Pad ':experimental(init_expr)';
 
-role Blockchain::Ethereum::Transaction {
-    use Carp;
-    use Digest::Keccak qw(keccak_256);
+package Blockchain::Ethereum::Transaction 0.005;
+role Blockchain::Ethereum::Transaction;
 
-    use Blockchain::Ethereum::RLP;
-
-    field $chain_id :reader :writer :param;
-    field $nonce :reader :writer :param;
-    field $gas_limit :reader :writer :param;
-    field $to :reader :writer :param    //= '';
-    field $value :reader :writer :param //= '0x0';
-    field $data :reader :writer :param  //= '';
-    field $v :reader :writer :param = undef;
-    field $r :reader :writer :param = undef;
-    field $s :reader :writer :param = undef;
-
-    field $rlp :reader = Blockchain::Ethereum::RLP->new();
-
-    # required methods
-    method serialize;
-    method generate_v;
-
-    method hash {
-
-        return keccak_256($self->serialize);
-    }
-}
-
-=pod
-
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
 Blockchain::Ethereum::Transaction - Ethereum transaction abstraction
 
-=head1 VERSION
-
-Version 0.004
-
-=cut
-
-our $VERSION = '0.004';
-
 =head1 SYNOPSIS
 
 In most cases you don't want to use this directly, use instead:
@@ -57,7 +22,24 @@ In most cases you don't want to use this directly, use instead:
 
 =back
 
-=head1 METHODS
+=cut
+
+use Carp;
+use Digest::Keccak qw(keccak_256);
+
+use Blockchain::Ethereum::RLP;
+
+field $chain_id :reader :writer :param;
+field $nonce :reader :writer :param;
+field $gas_limit :reader :writer :param;
+field $to :reader :writer :param    //= '';
+field $value :reader :writer :param //= '0x0';
+field $data :reader :writer :param  //= '';
+field $v :reader :writer :param = undef;
+field $r :reader :writer :param = undef;
+field $s :reader :writer :param = undef;
+
+field $rlp :reader = Blockchain::Ethereum::RLP->new();
 
 =head2 serialize
 
@@ -75,21 +57,7 @@ Returns the RLP encoded transaction bytes
 
 =cut
 
-=head2 hash
-
-SHA3 Hash the serialized transaction object
-
-Usage:
-
-    hash() -> SHA3 transaction hash
-
-=over 4
-
-=back
-
-Returns the SHA3 transaction hash bytes
-
-=cut
+method serialize;
 
 =head2 generate_v
 
@@ -109,6 +77,33 @@ Returns the v hexadecimal value also sets the v fields from transaction
 
 =cut
 
+method generate_v;
+
+=head2 hash
+
+SHA3 Hash the serialized transaction object
+
+Usage:
+
+    hash() -> SHA3 transaction hash
+
+=over 4
+
+=back
+
+Returns the SHA3 transaction hash bytes
+
+=cut
+
+method hash {
+
+    return keccak_256($self->serialize);
+}
+
+1;
+
+__END__
+
 =head1 AUTHOR
 
 Reginaldo Costa, C<< <refeco at cpan.org> >>
@@ -117,12 +112,6 @@ Reginaldo Costa, C<< <refeco at cpan.org> >>
 
 Please report any bugs or feature requests to L<https://github.com/refeco/perl-ethereum-transaction>
 
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Blockchain::Ethereum::Transaction
-
 =head1 LICENSE AND COPYRIGHT
 
 This software is Copyright (c) 2023 by REFECO.
@@ -132,5 +121,3 @@ This is free software, licensed under:
   The MIT License
 
 =cut
-
-1;
