@@ -1,43 +1,11 @@
 use v5.26;
 use Object::Pad;
 
-package Blockchain::Ethereum::Transaction::Legacy 0.004;
-class Blockchain::Ethereum::Transaction::Legacy :does(Blockchain::Ethereum::Transaction) {
-    field $gas_price :reader :writer :param;
+package Blockchain::Ethereum::Transaction::Legacy 0.005;
+class Blockchain::Ethereum::Transaction::Legacy
+    :does(Blockchain::Ethereum::Transaction);
 
-    method serialize {
-
-        my @params = (
-            $self->nonce,    #
-            $self->gas_price,
-            $self->gas_limit,
-            $self->to,
-            $self->value,
-            $self->data,
-        );
-
-        if ($self->v && $self->r && $self->s) {
-            push(@params, $self->v, $self->r, $self->s);
-        } else {
-            push(@params, $self->chain_id, '0x', '0x');
-        }
-
-        return $self->rlp->encode(\@params);
-    }
-
-    method generate_v ($y_parity) {
-
-        my $v = sprintf("0x%x", (hex $self->chain_id) * 2 + 35 + $y_parity);
-
-        $self->set_v($v);
-        return $v;
-    }
-
-};
-
-=pod
-
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
@@ -64,20 +32,11 @@ Transaction abstraction for Legacy transactions
     $key->sign_transaction($transaction);
 
     my $raw_transaction = $transaction->serialize;
-    ```
-
-=over 4
-
-=back
-
-=head1 METHODS
-
-=head2 sign
-
-Check the parent transaction class for details L<Blockchain::Ethereum::Transaction>
 
 =cut
 
+field $gas_price :reader :writer :param;
+
 =head2 serialize
 
 Encodes the given transaction parameters to RLP
@@ -94,6 +53,26 @@ Returns the RLP encoded transaction bytes
 
 =cut
 
+method serialize {
+
+    my @params = (
+        $self->nonce,    #
+        $self->gas_price,
+        $self->gas_limit,
+        $self->to,
+        $self->value,
+        $self->data,
+    );
+
+    if ($self->v && $self->r && $self->s) {
+        push(@params, $self->v, $self->r, $self->s);
+    } else {
+        push(@params, $self->chain_id, '0x', '0x');
+    }
+
+    return $self->rlp->encode(\@params);
+}
+
 =head2 generate_v
 
 Generate the transaction v field using the given y-parity
@@ -112,6 +91,18 @@ Returns the v hexadecimal value also sets the v fields from transaction
 
 =cut
 
+method generate_v ($y_parity) {
+
+    my $v = sprintf("0x%x", (hex $self->chain_id) * 2 + 35 + $y_parity);
+
+    $self->set_v($v);
+    return $v;
+}
+
+1;
+
+__END__
+
 =head1 AUTHOR
 
 Reginaldo Costa, C<< <refeco at cpan.org> >>
@@ -120,12 +111,6 @@ Reginaldo Costa, C<< <refeco at cpan.org> >>
 
 Please report any bugs or feature requests to L<https://github.com/refeco/perl-ethereum-transaction>
 
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Blockchain::Ethereum::Transaction::Legacy
-
 =head1 LICENSE AND COPYRIGHT
 
 This software is Copyright (c) 2023 by REFECO.
@@ -135,5 +120,3 @@ This is free software, licensed under:
   The MIT License
 
 =cut
-
-1;
